/*
 * message-menuitem.c - A menuitem subclass to display a notification message.
 */

#include <gtk/gtkhbox.h>
#include <gtk/gtkimage.h>
#include <gtk/gtklabel.h>
#include <stdio.h>
#include "message-menuitem.h"

static void message_menuitem_class_init(MessageMenuItemClass *klass);
static void message_menuitem_init(MessageMenuItem *item);

G_DEFINE_TYPE (MessageMenuItem, message_menuitem, GTK_TYPE_MENU_ITEM);

static void
message_menuitem_class_init(MessageMenuItemClass *klass)
{
}

static void
message_menuitem_init(MessageMenuItem *item)
{
  item->image = gtk_image_new();
  gtk_widget_show(item->image);

  item->label = gtk_label_new(NULL);
  gtk_label_set_use_markup(GTK_LABEL(item->label), TRUE);
  gtk_widget_show(item->label);

  item->hbox = gtk_hbox_new(FALSE, 0);
  gtk_box_pack_start(GTK_BOX(item->hbox), item->image, FALSE, FALSE, 15);
  gtk_box_pack_start(GTK_BOX(item->hbox), item->label, FALSE, FALSE, 0);
  gtk_container_add(GTK_CONTAINER(item), item->hbox);
  gtk_widget_show(item->hbox);
}

GtkWidget* 
message_menuitem_new(void)
{
  return GTK_WIDGET(g_object_new(MESSAGE_MENUITEM_TYPE, NULL));
}

/* TODO: Replace with message_menuitem_set_message(MessageMenuItem *item, Message *message);
 * once the notification code has been converted to gobjects
 */
void
message_menuitem_set_message(MessageMenuItem *item, 
    const char *summary,
    const char *body,
    const char *timestamp,
    const char *app_name,
    const char *icon_name)
{
  char buffer[1024];

  sprintf(buffer, "<b>%s</b>\n%s\n<small><i>%s from <b>%s</b></i></small>", summary,
      body, timestamp, app_name);

  gtk_image_set_from_icon_name(GTK_IMAGE(item->image), icon_name, GTK_ICON_SIZE_DIALOG);
  gtk_label_set_markup(GTK_LABEL(item->label), buffer);
}
