#include <stdlib.h>
#include <gtk/gtk.h>
#include <gio/gio.h>

#define NOTIFY_FILTER "type='method_call',interface='org.freedesktop.Notifications',member='Notify'"

GDBusMessage* 
message_filter(GDBusConnection *connection, GDBusMessage *message, gboolean incoming, gpointer user_data)
{
  gchar *debug_str;

  /* Discard incoming messages after looking at them */
  if(incoming) {
    debug_str = g_dbus_message_print(message, 0);
    g_print("Message Received:\n");
    g_print("%s\n", debug_str);
    g_free(debug_str);
    g_object_unref(message);
    message = NULL;
    return message;
  }
  /* Pass along outgoing messages */
  else {
    debug_str = g_dbus_message_print(message, 0);
    g_print("Message Sent:\n");
    g_print("%s\n", debug_str);
    g_free(debug_str);
    return message;
  }
}

int 
main(int argc, char* argv[])
{
  GDBusConnection *connection;
  GError *error = NULL;
  GBusType type = G_BUS_TYPE_SESSION;
  GDBusMessage *message;
  GVariant *body;
  GVariant *args[1];
  GVariant *arg;

  gtk_init(&argc, &argv);

  connection = g_bus_get_sync(type, NULL, &error);
  if(connection == NULL) {
    g_printerr("Failed to open connection to session bus: %s\n", error->message);
    g_error_free(error);
    exit(1);
  }

  message = g_dbus_message_new_method_call("org.freedesktop.DBus", "/org/freedesktop/DBus",
      "org.freedesktop.DBus", "AddMatch");

  arg = g_variant_new_string(NOTIFY_FILTER);
  args[0] = arg;

  body = g_variant_new_tuple(args, 1);

  g_dbus_message_set_body(message, body);

  g_dbus_connection_send_message(connection, message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, &error);
  if(error != NULL) {
    g_printerr("Failed to send message: %s\n", error->message);
    g_error_free(error);
    exit(1);
  }

  g_dbus_connection_add_filter(connection, message_filter, NULL, NULL);

  gtk_main();

  exit(0);
}
