#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <dbus/dbus.h>

#define NOTIFY_FILTER "type='method_call',interface='org.freedesktop.Notifications',member='Notify'"

#define MESSAGE_APPNAME 0
#define MESSAGE_SUMMARY 3
#define MESSAGE_BODY    4

static DBusHandlerResult 
monitor_filter_func(DBusConnection *connection, DBusMessage *message, void *user_data)
{
  DBusMessageIter iter;
  int message_type;
  int arg_type;
  int index = 0;
  char *value;

  printf("message received\n");

  message_type = dbus_message_get_type(message);
  if(message_type == DBUS_MESSAGE_TYPE_METHOD_CALL) {
    printf("received method_call\n");

    dbus_message_iter_init(message, &iter);
    do {
      arg_type = dbus_message_iter_get_arg_type(&iter);

      switch(arg_type) {
        case DBUS_TYPE_STRING:
          {
            dbus_message_iter_get_basic(&iter, &value);

            switch(index) {
              case MESSAGE_APPNAME:
                printf("appname: %s\n", value);
                break;
              case MESSAGE_SUMMARY:
                printf("summary: %s\n", value);
                break;
              case MESSAGE_BODY:
                printf("body: %s\n", value);
                break;
            }
            break;
          }
      }

      index++;
    } while(dbus_message_iter_next(&iter));
  }
  else {
    printf("received invalid message type: %d\n", message_type);
  }
  
  if(dbus_message_is_signal(message, DBUS_INTERFACE_LOCAL, "Disconnected"))
    exit(0);
  
  return DBUS_HANDLER_RESULT_HANDLED;
}

int 
main(int argc, char* argv[])
{
  DBusConnection *connection;
  DBusError error;
  DBusBusType type = DBUS_BUS_SESSION;
  DBusHandleMessageFunction filter_func = monitor_filter_func;

  dbus_error_init(&error);

  connection = dbus_bus_get(type, &error);
  if(connection == NULL) {
    fprintf(stderr, "Failed to open connection to session bus: %s\n", error.message);
    dbus_error_free(&error);
    exit(1);
  }

  dbus_bus_add_match(connection, NOTIFY_FILTER, &error);
  if(dbus_error_is_set(&error)) {
    fprintf(stderr, "Failed to add match: %s\n", error.message);
    dbus_error_free(&error);
    exit(1);
  }

  if(!dbus_connection_add_filter(connection, filter_func, NULL, NULL)) {
    fprintf(stderr, "Failed to add filter.\n");
    exit(1);
  }

  while(dbus_connection_read_write_dispatch(connection, -1)); 

  exit(0);
}
