"""
Preferences.py
February 13, 2011

Configure user preferences and the application blacklist.
"""

import gtk

from Translations import _

def show_preferences(parent):
  dialog = gtk.Dialog(_("Preferences"), buttons=(gtk.STOCK_CLOSE, gtk.RESPONSE_ACCEPT))
  dialog.set_default_size(400, 300)

  notebook = gtk.Notebook()
  dialog.vbox.pack_start(notebook)

  # General tab
  general_vbox = gtk.VBox()
  general_vbox.set_border_width(10)

  show_count_button = gtk.CheckButton(_("Display unread message count"))
  show_count_button.set_active(parent._preferences.get_bool("show_count", False))
  show_count_button.connect("toggled", lambda t: parent._preferences.set("show_count", t.get_active()))
  general_vbox.pack_start(show_count_button, False, False, 0)

  debug_button = gtk.CheckButton(_("Enable debug messages"))
  debug_button.set_active(parent._preferences.get_bool("debug", False))
  debug_button.connect("toggled", lambda t: parent._preferences.set("debug", t.get_active()))
  general_vbox.pack_start(debug_button, False, False, 0)

  message_limit_frame = gtk.Frame(_("Message Limit"))
  message_limit_vbox = gtk.VBox()
  message_limit_vbox.set_border_width(5)
  message_limit_frame.add(message_limit_vbox)
  message_limit_combo = gtk.combo_box_new_text()
  message_limit_combo.append_text(_("unlimited"))
  message_limit_combo.append_text(_("20"))
  message_limit_combo.append_text(_("40"))
  message_limit_combo.append_text(_("60"))
  message_limit_combo.append_text(_("80"))
  message_limit_combo.append_text(_("100"))

  n = parent._preferences.get_int("message_limit", 0)
  if 0 <= n <= 100:
    message_limit_combo.set_active(n / 20)
  else:
    message_limit_combo.set_active(0)

  message_limit_combo.connect("changed", lambda c: parent._preferences.set("message_limit", c.get_active() * 20))
  message_limit_vbox.pack_start(message_limit_combo, True, True, 0)
  general_vbox.pack_start(message_limit_frame, False, False, 0)


  general_label = gtk.Label(_("General"))
  notebook.append_page(general_vbox, general_label)

  # Blacklist tab
  blacklist_scroll = gtk.ScrolledWindow()
  blacklist_scroll.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)

  blacklist_vbox = gtk.VBox()
  blacklist_vbox.set_border_width(10)
  blacklist_scroll.add_with_viewport(blacklist_vbox)

  def do_blacklist(app_name):
    def wrapper(t):
      parent._blacklist.set(app_name, t.get_active())
    return wrapper

  items = parent.get_blacklist_items()
  if len(items) == 0:
    blacklist_vbox.pack_start(gtk.Label(_("The blacklist is currently empty.")), True, True, 0)
  else:
    for app_name, active in parent.get_blacklist_items():
      app_button = gtk.CheckButton(app_name)
      app_button.set_active(active)
      app_button.connect("toggled", do_blacklist(app_name))
      blacklist_vbox.pack_start(app_button, False, False, 0)

  blacklist_label = gtk.Label(_("Blacklist"))
  notebook.append_page(blacklist_scroll, blacklist_label)

  dialog.show_all()
  response = dialog.run()
  dialog.destroy()
