"""
test_config.py
April 24, 2011

Tests unity.Config
"""

import os
import unittest
import sys

SCRIPT_PATH = os.path.dirname(os.path.abspath(__file__))

# Insert the unity module into the search path
APP_PATH = os.path.abspath(os.path.join(SCRIPT_PATH, ".."))
sys.path.insert(0, APP_PATH)

CONFIG_PATH = os.path.join(SCRIPT_PATH, "configs")

from unity.Config import Config, ConfigException

def get_path(config_file):
  return os.path.join(CONFIG_PATH, config_file)

def delete_path(config_file):
  try:
    os.remove(get_path(config_file))
  except:
    pass

class TestConfig(unittest.TestCase):
  def setUp(self):
    pass

  def test_set(self):
    # Remove the old config
    delete_path("test_set")

    config = Config(get_path("test_set"))

    config.set("key", "value")
    self.assertEqual(config.get("key"), "value")

    with self.assertRaises(ConfigException):
      config.set("", "value")

  def test_set_if_unset(self):
    # Remove the old config
    delete_path("test_set_if_unset")

    config = Config(get_path("test_set_if_unset"))

    config.set_if_unset("key", "value_1")
    self.assertEqual(config.get("key"), "value_1")

    config.set_if_unset("key", "value_2")
    self.assertEqual(config.get("key"), "value_1")

  def test_get(self):
    config = Config(get_path("sample"))

    self.assertEqual(config.get("apple"), "This is an apple")
    self.assertEqual(config.get("cake"), "delicious")

    # Test for missing value returning proper default
    self.assertEqual(config.get("missing_value", "default"), "default")

  def test_get_bool(self):
    config = Config(get_path("sample"))

    self.assertEqual(config.get_bool("boolean_value_1"), True)
    self.assertEqual(config.get_bool("boolean_value_2"), True)
    self.assertEqual(config.get_bool("false_value"), False)

    # Test for missing value returning proper default
    self.assertEqual(config.get_bool("missing_value", False), False)

    # Test for invalid value returning proper default
    self.assertEqual(config.get_bool("one", False), False)

  def test_get_int(self):
    config = Config(get_path("sample"))

    self.assertEqual(config.get_int("one"), 1)
    self.assertEqual(config.get_int("two"), 2)
    self.assertEqual(config.get_int("three"), 3)
    self.assertEqual(config.get_int("four"), 4)

    # Test for missing value returning proper default
    self.assertEqual(config.get_int("missing_value", 0), 0)

    # Test for invalid value returning proper default
    self.assertEqual(config.get_int("cake", 0), 0)

if __name__ == '__main__':
  unittest.main()
